import card
from random import shuffle

class Deck(object):
    """A deck of Cards."""

    # The four suits, representing Clubs, Diamonds, Hearts, and Spades.
    SUITS = ['C', 'D', 'H', 'S']

    # The 13 ranks, representing
    # 2, 3, ..., 9, 10, Jack, Queen, King, and Ace.
    RANKS = ['2', '3', '4', '5', '6', '7', '8', '9', 'T', 'J', 'Q', 'K', 'A']

    def __init__(self):
        '''A new deck with 52 face-down cards.'''

        # The top card is at self.cards[-1]
        self.cards = []
        for suit in Deck.SUITS:
            for rank in Deck.RANKS:
                self.cards.append(card.Card(suit, rank))

    def shuffle(self):
        '''Randomly rearrange the cards.'''

        shuffle(self.cards)
        
    def empty(self):
        '''Return True iff this deck has no cards.'''
        
        return len(self.cards) == 0
    
    def get_next_card(self):
        '''Remove and return this deck's next Card, face down.'''

        return self.cards.pop()
